/* File: universal_memory_arena_test.h; Copyright and License: see below */

#ifndef UNIVERSAL_MEMORY_ARENA_TEST_H
#define UNIVERSAL_MEMORY_ARENA_TEST_H

/*!
 *  \file
 *  \brief UNITTEST for universal_memory_arena
 */

#include "test_suite.h"

test_suite_t universal_memory_arena_test_get_suite(void);

#endif  /* UNIVERSAL_MEMORY_ARENA_TEST_H */


/*
 * Copyright 2021-2021 Andreas Warnke
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
